@@ -50,6 +50,9 @@ exec("from "+prefix+"getProfitAbility import getProfitAbility")  #ยกเล
 #from starfishX.starfishXfn import getMemberOfIndex
 exec("from "+prefix+"starfishXfn import getMemberOfIndex")
 
+#from starfishX.starfishXfn import getMemberOfIndex
+exec("from "+prefix+"starfishXfn import getDividendYieldOfIndex")
+
 #from starfishX.starfishXfn import listStockInSector
 # exec("from "+prefix+"starfishXfn import listStockInSector")
 
@@ -180,7 +183,7 @@ exec("from "+prefix+"risk_kit import *")
 exec("from "+prefix+"nvdr import getNVDRVolume")
 exec("from "+prefix+"nvdr import reduceXtickfrequency") 
 
-
+exec("from "+prefix+"news_api import news_api_bydate")
 exec("from "+prefix+"news_api import news_api")
 exec("from "+prefix+"news_api import NewsTypeMatch")
 
@@ -210,6 +213,6 @@ exec("from "+prefix+"greek import EuropeanCallRolling")
 #exec("from "+prefix+"utilHelpers import HistStockPrice")
  
 
-__version__ = 0.155538  #11 กุมภาพันธ์ 2565 update 0.155536
+__version__ = 0.155549  #21 Feb 2023 update 0.155549
 
 __doc__ = """starfishX Version จัดเตรียมข้อมูลสำหรับประมวลผลการลงทุนในตลาดหุ้นไทย """
\ No newline at end of file
